""" Custom error definitions for data-fetcher """

import logging

_LOG = logging.getLogger(__name__)

# pylint: disable=W1202


errors = [
    (1, "NoProfileException", "no CAPO profile provided"),
    (2, "MissingSettingsException", "missing required setting"),
    (
        3,
        "LocationServiceTimeoutException",
        "request to locator service timed out",
    ),
    (
        4,
        "LocationServiceRedirectsException",
        "too many redirects on locator service",
    ),
    (
        5,
        "LocationServiceErrorException",
        "catastrophic error on locator service",
    ),
    (6, "NoLocatorException", "product locator not found"),
    (7, "FileErrorException", "not able to open specified location file"),
    (8, "NGASServiceTimeoutException", "request to NGAS timed out"),
    (
        9,
        "NGASServiceRedirectsException",
        "too many redirects on NGAS service",
    ),
    (10, "NGASServiceErrorException", "catastrophic error on NGAS service"),
    (11, "SizeMismatchException", "retrieved file not expected size"),
    (12, "FileExistsError", "specified location file exists"),
    (13, "FileNotFoundError", "target directory or file not found"),
    (14, "NGASFetchError", "trouble retrieving files from NGAS"),
]


class DataFetcherException(Exception):
    code: int
    message: str


def define_datafetcher_exception(code, name, message):
    result = type(name, (DataFetcherException,), {})
    result.code, result.message = code, message
    return result


# Define the exceptions
NoProfileException = define_datafetcher_exception(*errors[0])
MissingSettingsException = define_datafetcher_exception(*errors[1])
LocationServiceTimeoutException = define_datafetcher_exception(*errors[2])
LocationServiceRedirectsException = define_datafetcher_exception(*errors[3])
LocationServiceErrorException = define_datafetcher_exception(*errors[4])
NoLocatorException = define_datafetcher_exception(*errors[5])
FileErrorException = define_datafetcher_exception(*errors[6])
NGASServiceTimeoutException = define_datafetcher_exception(*errors[7])
NGASServiceRedirectsException = define_datafetcher_exception(*errors[8])
NGASServiceErrorException = define_datafetcher_exception(*errors[9])
SizeMismatchException = define_datafetcher_exception(*errors[10])
FileExistsError = define_datafetcher_exception(*errors[11])
FileNotFoundError = define_datafetcher_exception(*errors[12])
NGASFetchError = define_datafetcher_exception(*errors[13])


TERMINAL_ERROR_CODES = "Return Codes:\n"
for error_code, exception_name, message in errors:
    TERMINAL_ERROR_CODES += f"\t{error_code}: {message}\n"
