"""
Our custom errors.

We create a simple taxonomy of errors: they are all FetchErrors, but some are RetryableFetchErrors.
The distinction matters to the RetryingFileFetcher, which will re-attempt a fetch only
if it is interrupted by a RetryableFetchError.

"""


class FetchError(Exception):
    """
    Some sort of problem has occurred, and the program must end.
    """


class RetryableFetchError(FetchError):
    """
    A problem has occurred, but one that may go away if you try
    again in a few seconds.
    """


class FileValidationFault(FetchError):
    """
    A file has failed to validate for some reason. This is not a retryable error.
    """


class UnsatisfiableConstraint(FetchError):
    """
    Something the user has asked for is impossible. For instance, insisting
    on an NGAS direct copy with a destination that NGAS cannot see.
    """


class NormalModeFileExistsError(FetchError):
    """
    Shadows the built-in FileExistsError, but intended to be raised by the ForceMode.
    Not a retryable error, the file will continue to be in place each time.
    """


class NgasServiceErrorException(FetchError):
    """
    Problems that occur during fetching from NGAS are covered by this exception.
    """


class LocatorServiceException(FetchError):
    """
    Problems that occur when trying to reach the locator service
    """
