""" Tests for our size, checksum, and SDM table XML validators """
import pathlib

# pylint: disable=E0401, E0402

import pytest

from datafetcher.redesign.exceptions import FileValidationFault
from datafetcher.redesign.validators import Crc32Validator, SizeValidator, XmlWellFormedValidator


def test_size_validator(resource_path_root: pathlib.Path, capsys):
    """
    Does the size validator function as expected?

    :param resource_path_root:
    :param capsys:
    :return:
    """
    # this should work just fine
    SizeValidator(1024).validate(resource_path_root / "validators" / "random-junk")

    # these should not
    with pytest.raises(FileValidationFault):
        SizeValidator(1023).validate(resource_path_root / "validators" / "random-junk")

    with pytest.raises(FileValidationFault):
        SizeValidator(1025).validate(resource_path_root / "validators" / "random-junk")
    capsys.readouterr()


def test_checksum_validator(resource_path_root: pathlib.Path, capsys):
    """
    Does the checksum validator function as expected?

    :param resource_path_root:
    :param capsys:
    :return:
    """
    # this should work just fine
    Crc32Validator(457325410).validate(resource_path_root / "validators" / "random-junk")

    # this should raise an error
    with pytest.raises(FileValidationFault):
        Crc32Validator(457325411).validate(resource_path_root / "validators" / "random-junk")

    # so should this
    with pytest.raises(FileValidationFault):
        Crc32Validator(-1).validate(resource_path_root / "validators" / "random-junk")
    capsys.readouterr()


def test_xml_validator(resource_path_root: pathlib.Path, capsys):
    """
    Determine whether the XML we pulled down is well-formed.

    :param resource_path_root:
    :param capsys:
    :return:
    """
    XmlWellFormedValidator().validate(resource_path_root / "validators" / "valid.xml")

    with pytest.raises(FileValidationFault):
        XmlWellFormedValidator().validate(resource_path_root / "validators" / "invalid.xml")
    capsys.readouterr()
