"""
Tests for Vela
"""
import os
from unittest.mock import patch, mock_open

from vela.quasar import CalibrationEmulator


class TestCalibrationEmulator:
    @patch("os.chdir")
    @patch("vela.forger.VelaProduct.forge_cal_products")
    @patch("vela.forger.VelaLog.forge_logs")
    def test_run(self, mock_logs, mock_products, mock_os):
        with patch("vela.forger.forge") as forge:
            CalibrationEmulator("test/test.json", "test/PPR.xml").run()
            forge.call_count == 1

    def test_setup_environment(self):
        parameters = {"useCasa": False,
                      "homeForReprocessing": "/home/casa/packages/pipeline/current",
                      "rootDirectory": "/tmp/workspaces_tmp/"}
        CalibrationEmulator("test.json", "PPR.xml").setup_environment(parameters=parameters)
        assert os.environ.get('SCIPIPE_ROOTDIR') == parameters["rootDirectory"]
        assert os.environ.get('CASA_HOME') == parameters["homeForReprocessing"]
        assert os.environ.get('PPR_FILENAME') == "PPR.xml"

    @patch("os.chdir")
    def test_check_logs(self, mock_os):
        with patch("builtins.open", mock_open()) as o:
            CalibrationEmulator("test.json", "PPR.xml").check_logs()
            o.call_count == 1
