""" Proof of concept: uses marshmallow to load locations report JSON
    directly into a ClassyLocationsReport!
"""

import json

# pylint: disable=E0401, E0402, W0611, W0621

from pathlib import Path

from datafetcher.locations_report import (
    NgasFile,
    LocationsReport,
    LocationsReportSchema,
    NgasFileSchema,
)

from .conftest import (
    get_file_info_from_json_file,
    vla_small_eb_locations_report,
    vla_small_locations_file,
    eb_17a_109_18468_locations_file,
)


def test_loads_filespec():
    """
    Can marshmallow load one of the "files" sections in a JSON locations report?

    :return:
    """
    server_dict = {
        "server": "nmngas04.aoc.nrao.edu:7777",
        "location": "DSOC",
        "cluster": "DSOC",
    }
    filespec_dict = {
        "ngas_file_id": "uid____EVLA_calibration_d20461ec-b0ad-44fe-86ad-a25b7a97e4c6.tar",
        "subdirectory": "18B-265_2019_12_10_T00_00_59.203.tar",
        "relative_path": "18B-265_2019_12_10_T00_00_59.203.tar",
        "checksum": "722663767",
        "checksum_type": "ngamsGenCrc32",
        "version": 1,
        "size": 27668480,
        "server": server_dict,
    }
    schema = NgasFileSchema()
    json_str = json.dumps(filespec_dict)
    ngas_filespec = schema.loads(json_str)
    assert isinstance(ngas_filespec, NgasFile)


def test_loads_simple_locations_report(cal_json_file):
    """
    Can marshmallow load an entire JSON locations report?

    :return:
    """
    schema = LocationsReportSchema()
    locations_dict = get_file_info_from_json_file(cal_json_file)
    json_str = json.dumps(locations_dict)
    locations_rpt = schema.loads(json_str)
    assert isinstance(locations_rpt, LocationsReport)


def test_loads_complex_locations_report(eb_17a_109_18468_locations_file):
    """
    Can marshmallow load an entire JSON locations report?

    :return:
    """
    schema = LocationsReportSchema()
    loc_file = Path(eb_17a_109_18468_locations_file)
    locations_dict = get_file_info_from_json_file(loc_file)
    json_str = json.dumps(locations_dict)
    locations_rpt = schema.loads(json_str)
    assert isinstance(locations_rpt, LocationsReport)

    files = locations_rpt.targets
    assert len(files) == 79
    assert locations_rpt.aggregate_size == 45572444823


def test_loads_alma_locations_report(alma_execblock_report):
    """
    Can marshmallow load an entire JSON locations report?

    :return:
    """
    schema = LocationsReportSchema()
    loc_file = Path(alma_execblock_report)
    locations_dict = get_file_info_from_json_file(loc_file)
    json_str = json.dumps(locations_dict)
    locations_rpt = schema.loads(json_str)
    assert isinstance(locations_rpt, LocationsReport)

    assert len(locations_rpt.alma_sdms) == 36
    assert len(locations_rpt.ngas_files) == 1063
    assert locations_rpt.aggregate_size == 4119667881
